@@ -52,6 +52,9 @@ typedef enum
 	COMPOSE_REPLY_TO_ALL,
 	COMPOSE_REPLY_TO_ALL_WITH_QUOTE,
 	COMPOSE_REPLY_TO_ALL_WITHOUT_QUOTE,
+	COMPOSE_REPLY_TO_LIST,
+	COMPOSE_REPLY_TO_LIST_WITH_QUOTE,
+	COMPOSE_REPLY_TO_LIST_WITHOUT_QUOTE,
 	COMPOSE_FORWARD,
 	COMPOSE_FORWARD_AS_ATTACH,
 	COMPOSE_NEW,
@@ -125,6 +128,8 @@ struct _Compose
 	gchar	*newsgroups;
 	gchar	*followup_to;
 
+	gchar	*ml_post;
+
 	gchar	*inreplyto;
 	gchar	*references;
 	gchar	*msgid;
@@ -134,6 +139,7 @@ struct _Compose
 	gboolean use_cc;
 	gboolean use_bcc;
 	gboolean use_replyto;
+	gboolean use_newsgroups;
 	gboolean use_followupto;
 	gboolean use_attach;
 
@@ -149,7 +155,6 @@ struct _Compose
 	GSList *newsgroup_list;
 
 	PrefsAccount *account;
-	PrefsAccount *orig_account;
 
 	UndoMain *undostruct;
 
@@ -176,6 +181,7 @@ void compose_new		(PrefsAccount	*account,
 void compose_reply		(MsgInfo	*msginfo,
 				 gboolean	 quote,
 				 gboolean	 to_all,
+				 gboolean	 to_ml,
 				 gboolean	 ignore_replyto,
 				 const gchar	*body);
 void compose_forward		(GSList		*mlist,
