@@ -188,7 +188,12 @@ static gint inc_account_mail(PrefsAccount *account, MainWindow *mainwin)
 	gchar *text[3];
 
 	if (account->protocol == A_IMAP4 || account->protocol == A_NNTP) {
+		FolderItem *item = mainwin->summaryview->folder_item;
+
 		folderview_check_new(FOLDER(account->folder));
+		if (!prefs_common.scan_all_after_inc && item != NULL &&
+		    FOLDER(account->folder) == item->folder)
+			folderview_update_item(item, TRUE);
 		return 1;
 	}
 
@@ -241,8 +246,14 @@ void inc_all_account_mail(MainWindow *mainwin)
 	for (; list != NULL; list = list->next) {
 		PrefsAccount *account = list->data;
 		if ((account->protocol == A_IMAP4 ||
-		     account->protocol == A_NNTP) && account->recv_at_getall)
+		     account->protocol == A_NNTP) && account->recv_at_getall) {
+			FolderItem *item = mainwin->summaryview->folder_item;
+
 			folderview_check_new(FOLDER(account->folder));
+			if (!prefs_common.scan_all_after_inc && item != NULL &&
+			    FOLDER(account->folder) == item->folder)
+				folderview_update_item(item, TRUE);
+		}
 	}
 
 	/* check POP3 accounts */
@@ -821,7 +832,8 @@ gint inc_drop_message(const gchar *file, Pop3State *state)
 			filter_get_dest_folder(prefs_common.fltlist, file);
 		if (!dropfolder) dropfolder = inbox;
 		else if (!strcmp(dropfolder->path, FILTER_NOT_RECEIVE)) {
-			g_warning(_("a message won't be received\n"));
+			debug_print(_("a message won't be received\n"));
+			unlink(file);
 			return 1;
 		}
 	} else
