@@ -370,6 +370,9 @@ static void copy_cb		 (MainWindow	*mainwin,
 static void allsel_cb		 (MainWindow	*mainwin,
 				  guint		 action,
 				  GtkWidget	*widget);
+static void select_thread_cb	 (MainWindow	*mainwin,
+				  guint		 action,
+				  GtkWidget	*widget);
 
 static void create_filter_cb	 (MainWindow	*mainwin,
 				  guint		 action,
@@ -433,6 +436,7 @@ static GtkItemFactoryEntry mainwin_entries[] =
 	{N_("/_Edit"),				NULL, NULL, 0, "<Branch>"},
 	{N_("/_Edit/_Copy"),			"<control>C", copy_cb, 0, NULL},
 	{N_("/_Edit/Select _all"),		"<control>A", allsel_cb, 0, NULL},
+	{N_("/_Edit/Select _thread"),		NULL, select_thread_cb, 0, NULL},
 	{N_("/_Edit/---"),			NULL, NULL, 0, "<Separator>"},
 	{N_("/_Edit/_Find in current message..."),
 						"<control>F", search_cb, 0, NULL},
@@ -608,8 +612,11 @@ static GtkItemFactoryEntry mainwin_entries[] =
 	{N_("/_Message/Compose _new message"),	"<control>M",	compose_cb, 0, NULL},
 	{N_("/_Message/---"),			NULL, NULL, 0, "<Separator>"},
 	{N_("/_Message/_Reply"),		"<control>R", 	reply_cb, COMPOSE_REPLY, NULL},
-	{N_("/_Message/Reply to a_ll"),		"<shift><control>R", reply_cb, COMPOSE_REPLY_TO_ALL, NULL},
-	{N_("/_Message/Repl_y to sender"),	NULL, reply_cb, COMPOSE_REPLY_TO_SENDER, NULL},
+	{N_("/_Message/Repl_y to"),		NULL, NULL, 0, "<Branch>"},
+	{N_("/_Message/Repl_y to/_all"),	"<shift><control>R", reply_cb, COMPOSE_REPLY_TO_ALL, NULL},
+	{N_("/_Message/Repl_y to/_sender"),	NULL, reply_cb, COMPOSE_REPLY_TO_SENDER, NULL},
+	{N_("/_Message/Repl_y to/mailing _list"),
+						"<control>L", reply_cb, COMPOSE_REPLY_TO_LIST, NULL},
 	{N_("/_Message/---"),			NULL, NULL, 0, "<Separator>"},
 	{N_("/_Message/_Forward"),		"<control><alt>F", reply_cb, COMPOSE_FORWARD, NULL},
 	{N_("/_Message/For_ward as attachment"),
@@ -654,7 +661,7 @@ static GtkItemFactoryEntry mainwin_entries[] =
 	{N_("/_Tools/---"),			NULL, NULL, 0, "<Separator>"},
 	{N_("/_Tools/E_xecute"),		"X", execute_summary_cb, 0, NULL},
 	{N_("/_Tools/---"),			NULL, NULL, 0, "<Separator>"},
-	{N_("/_Tools/_Log window"),		"<control>L", log_window_show_cb, 0, NULL},
+	{N_("/_Tools/_Log window"),		"<shift><control>L", log_window_show_cb, 0, NULL},
 
 	{N_("/_Configuration"),			NULL, NULL, 0, "<Branch>"},
 	{N_("/_Configuration/_Common preferences..."),
@@ -1407,6 +1414,8 @@ void main_window_set_menu_sensitive(MainWindow *mainwin)
 		/* {"/File/Close"  , M_UNLOCKED}, */
 		{"/File/Exit"      , M_UNLOCKED},
 
+		{"/Edit/Select thread"             , M_SINGLE_TARGET_EXIST},
+
 		{"/View/Sort"                      , M_EXEC},
 		{"/View/Thread view"               , M_EXEC},
 		{"/View/Expand all threads"        , M_MSG_EXIST},
@@ -1430,8 +1439,7 @@ void main_window_set_menu_sensitive(MainWindow *mainwin)
 		{"/Message/Cancel receiving"     , M_INC_ACTIVE},
 		{"/Message/Compose new message"  , M_HAVE_ACCOUNT},
 		{"/Message/Reply"                , M_HAVE_ACCOUNT|M_SINGLE_TARGET_EXIST},
-		{"/Message/Reply to sender"      , M_HAVE_ACCOUNT|M_SINGLE_TARGET_EXIST},
-		{"/Message/Reply to all"         , M_HAVE_ACCOUNT|M_SINGLE_TARGET_EXIST},
+		{"/Message/Reply to"             , M_HAVE_ACCOUNT|M_SINGLE_TARGET_EXIST},
 		{"/Message/Forward"              , M_HAVE_ACCOUNT|M_TARGET_EXIST},
 		{"/Message/Forward as attachment", M_HAVE_ACCOUNT|M_TARGET_EXIST},
 		{"/Message/Redirect"             , M_HAVE_ACCOUNT|M_SINGLE_TARGET_EXIST},
@@ -1964,7 +1972,10 @@ static void toolbar_reply_cb	(GtkWidget	*widget,
 {
 	MainWindow *mainwin = (MainWindow *)data;
 
-	reply_cb(mainwin, COMPOSE_REPLY, NULL);
+	if (prefs_common.default_reply_list)
+		reply_cb(mainwin, COMPOSE_REPLY_TO_LIST, NULL);
+	else
+		reply_cb(mainwin, COMPOSE_REPLY, NULL);
 }
 
 static void toolbar_reply_to_all_cb	(GtkWidget	*widget,
@@ -2622,6 +2633,12 @@ static void allsel_cb(MainWindow *mainwin, guint action, GtkWidget *widget)
 		messageview_select_all(msgview);
 }
 
+static void select_thread_cb(MainWindow *mainwin, guint action,
+			     GtkWidget *widget)
+{
+	summary_select_thread(mainwin->summaryview);
+}
+
 static void create_filter_cb(MainWindow *mainwin, guint action,
 			     GtkWidget *widget)
 {
