@@ -21,6 +21,7 @@
 #define __NEWS_H__
 
 #include <glib.h>
+#include <stdio.h>
 
 #include "folder.h"
 #include "session.h"
@@ -79,5 +80,7 @@ void news_remove_group_list_cache	(Folder		*folder);
 
 gint news_post				(Folder		*folder,
 					 const gchar	*file);
+gint news_post_stream			(Folder		*folder,
+					 FILE		*fp);
 
 #endif /* __NEWS_H__ */
