@@ -58,7 +58,8 @@
 		     size > ac->size_limit * 1024);				\
 										\
 		if (ac->rmmail &&						\
-		    msg->recv_time != 0 &&					\
+		    msg->recv_time != RECV_TIME_NONE &&				\
+		    msg->recv_time != RECV_TIME_KEEP &&				\
 		    state->current_time - msg->recv_time >=			\
 		    ac->msg_leave_time * 24 * 60 * 60) {			\
 			log_print(_("POP3: Deleting expired message %d\n"),	\
@@ -332,8 +333,11 @@ gint pop3_getrange_uidl_recv(SockInfo *sock, gpointer data)
 	gint len;
 
 	if (!state->uidl_table) new = TRUE;
+#if 0
 	if (state->ac_prefs->getall ||
 	    (state->ac_prefs->rmmail && state->ac_prefs->msg_leave_time == 0))
+#endif
+	if (state->ac_prefs->getall)
 		get_all = TRUE;
 
 	if (pop3_ok(sock, NULL) != PS_SUCCESS) {
@@ -360,11 +364,12 @@ gint pop3_getrange_uidl_recv(SockInfo *sock, gpointer data)
 		recv_time = (time_t)g_hash_table_lookup(state->uidl_table, id);
 		state->msg[num].recv_time = recv_time;
 
-		if (!get_all && recv_time != 0)
+		if (!get_all && recv_time != RECV_TIME_NONE)
 			state->msg[num].received = TRUE;
 
 		if (new == FALSE &&
-		    (get_all || recv_time == 0 || state->ac_prefs->rmmail)) {
+		    (get_all || recv_time == RECV_TIME_NONE ||
+		     state->ac_prefs->rmmail)) {
 			state->cur_msg = num;
 			new = TRUE;
 		}
@@ -451,6 +456,7 @@ gint pop3_retr_recv(SockInfo *sock, gpointer data)
 			return -1;
 		}
 
+		/* drop_ok: 0: success 1: don't receive -1: error */
 		drop_ok = inc_drop_message(file, state);
 		g_free(file);
 		if (drop_ok < 0) {
@@ -463,9 +469,10 @@ gint pop3_retr_recv(SockInfo *sock, gpointer data)
 		state->cur_total_num++;
 
 		state->msg[state->cur_msg].received = TRUE;
-		state->msg[state->cur_msg].recv_time = state->current_time;
+		state->msg[state->cur_msg].recv_time =
+			drop_ok == 1 ? RECV_TIME_KEEP : state->current_time;
 
-		if (state->ac_prefs->rmmail &&
+		if (drop_ok == 0 && state->ac_prefs->rmmail &&
 		    state->ac_prefs->msg_leave_time == 0)
 			return POP3_DELETE_SEND;
 
@@ -649,8 +656,8 @@ GHashTable *pop3_get_uidl_table(PrefsAccount *ac_prefs)
 	GHashTable *table;
 	gchar *path;
 	FILE *fp;
-	gchar buf[IDLEN + 3];
-	gchar uidl[IDLEN + 3];
+	gchar buf[POPBUFSIZE];
+	gchar uidl[POPBUFSIZE];
 	time_t recv_time;
 	time_t now;
 
@@ -677,15 +684,15 @@ GHashTable *pop3_get_uidl_table(PrefsAccount *ac_prefs)
 
 	while (fgets(buf, sizeof(buf), fp) != NULL) {
 		strretchomp(buf);
-		recv_time = 0;
+		recv_time = RECV_TIME_NONE;
 		if (sscanf(buf, "%s\t%ld", uidl, &recv_time) != 2) {
 			if (sscanf(buf, "%s", uidl) != 1)
 				continue;
 			else
 				recv_time = now;
 		}
-		if (recv_time == 0)
-			recv_time = 1;
+		if (recv_time == RECV_TIME_NONE)
+			recv_time = RECV_TIME_RECEIVED;
 		g_hash_table_insert(table, g_strdup(uidl),
 				    GINT_TO_POINTER(recv_time));
 	}
