@@ -112,7 +112,7 @@ GpgmegtkSigStatus gpgmegtk_sig_status_create(void)
 	gtk_widget_set_usize(window, 400, -1);
 	gtk_container_set_border_width(GTK_CONTAINER(window), 8);
 	gtk_window_set_position(GTK_WINDOW(window), GTK_WIN_POS_CENTER);
-	gtk_window_set_policy(GTK_WINDOW(window), FALSE, FALSE, FALSE);
+	gtk_window_set_policy(GTK_WINDOW(window), FALSE, TRUE, FALSE);
 	gtk_signal_connect(GTK_OBJECT(window), "delete_event",
 			   GTK_SIGNAL_FUNC(delete_event), hd);
 	gtk_signal_connect(GTK_OBJECT(window), "key_press_event",
@@ -193,9 +193,9 @@ void gpgmegtk_sig_status_update(GpgmegtkSigStatus hd, GpgmeCtx ctx)
 		} else
 			userid = "[?]";
 
-		tmp = g_strdup_printf("%s%s%s from \"%s\"",
-				      text? text : "",
-				      text? "\n" : "",
+		tmp = g_strdup_printf(_("%s%s%s from \"%s\""),
+				      text ? text : "",
+				      text ? "\n" : "",
 				      gpgmegtk_sig_status_to_string(status),
 				      userid);
 		g_free (text);
