@@ -1341,6 +1341,63 @@ void decode_uri(gchar *decoded_uri, const gchar *encoded_uri)
 	*dec = '\0';
 }
 
+gint scan_mailto_url(const gchar *mailto, gchar **to, gchar **cc, gchar **bcc,
+		     gchar **subject, gchar **body)
+{
+	gchar *tmp_mailto;
+	gchar *p;
+
+	Xstrdup_a(tmp_mailto, mailto, return -1);
+
+	if (!strncmp(tmp_mailto, "mailto:", 7))
+		tmp_mailto += 7;
+
+	p = strchr(tmp_mailto, '?');
+	if (p) {
+		*p = '\0';
+		p++;
+	}
+
+	if (to && !*to)
+		*to = g_strdup(tmp_mailto);
+
+	while (p) {
+		gchar *field, *value;
+
+		field = p;
+
+		p = strchr(p, '=');
+		if (!p) break;
+		*p = '\0';
+		p++;
+
+		value = p;
+
+		p = strchr(p, '&');
+		if (p) {
+			*p = '\0';
+			p++;
+		}
+
+		if (*value == '\0') continue;
+
+		if (cc && !*cc && !g_strcasecmp(field, "cc")) {
+			*cc = g_strdup(value);
+		} else if (bcc && !*bcc && !g_strcasecmp(field, "bcc")) {
+			*bcc = g_strdup(value);
+		} else if (subject && !*subject &&
+			   !g_strcasecmp(field, "subject")) {
+			*subject = g_malloc(strlen(value) + 1);
+			decode_uri(*subject, value);
+		} else if (body && !*body && !g_strcasecmp(field, "body")) {
+			*body = g_malloc(strlen(value) + 1);
+			decode_uri(*body, value);
+		}
+	}
+
+	return 0;
+}
+
 /*
  * We need this wrapper around g_get_home_dir(), so that
  * we can fix some Windoze things here.  Should be done in glibc of course
@@ -1996,6 +2053,64 @@ gint move_file(const gchar *src, const gchar *dest, gboolean overwrite)
 	return 0;
 }
 
+gint copy_file_part(FILE *fp, off_t offset, size_t length, const gchar *dest)
+{
+	FILE *dest_fp;
+	gint n_read;
+	gint bytes_left, to_read;
+	gchar buf[BUFSIZ];
+	gboolean err = FALSE;
+
+	if (fseek(fp, offset, SEEK_SET) < 0) {
+		perror("fseek");
+		return -1;
+	}
+
+	if ((dest_fp = fopen(dest, "wb")) == NULL) {
+		FILE_OP_ERROR(dest, "fopen");
+		return -1;
+	}
+
+	if (change_file_mode_rw(dest_fp, dest) < 0) {
+		FILE_OP_ERROR(dest, "chmod");
+		g_warning("can't change file mode\n");
+	}
+
+	bytes_left = length;
+	to_read = MIN(bytes_left, sizeof(buf));
+
+	while ((n_read = fread(buf, sizeof(gchar), to_read, fp)) > 0) {
+		if (n_read < to_read && ferror(fp))
+			break;
+		if (fwrite(buf, n_read, 1, dest_fp) < 1) {
+			g_warning(_("writing to %s failed.\n"), dest);
+			fclose(dest_fp);
+			unlink(dest);
+			return -1;
+		}
+		bytes_left -= n_read;
+		if (bytes_left == 0)
+			break;
+		to_read = MIN(bytes_left, sizeof(buf));
+	}
+
+	if (ferror(fp)) {
+		perror("fread");
+		err = TRUE;
+	}
+	if (fclose(dest_fp) == EOF) {
+		FILE_OP_ERROR(dest, "fclose");
+		err = TRUE;
+	}
+
+	if (err) {
+		unlink(dest);
+		return -1;
+	}
+
+	return 0;
+}
+
 /* convert line endings into CRLF. If the last line doesn't end with
  * linebreak, add it.
  */
