@@ -286,6 +286,12 @@ gchar *trim_string			(const gchar	*str,
 GList *uri_list_extract_filenames	(const gchar	*uri_list);
 void decode_uri				(gchar		*decoded_uri,
 					 const gchar	*encoded_uri);
+gint scan_mailto_url			(const gchar	*mailto,
+					 gchar	       **to,
+					 gchar	       **cc,
+					 gchar	       **bcc,
+					 gchar	       **subject,
+					 gchar	       **body);
 
 /* return static strings */
 gchar *get_home_dir		(void);
@@ -328,6 +334,10 @@ gint copy_file			(const gchar	*src,
 gint move_file			(const gchar	*src,
 				 const gchar	*dest,
 				 gboolean	 overwrite);
+gint copy_file_part		(FILE		*fp,
+				 off_t		 offset,
+				 size_t		 length,
+				 const gchar	*dest);
 gint canonicalize_file		(const gchar	*src,
 				 const gchar	*dest);
 gint canonicalize_file_replace	(const gchar	*file);
